@@ -60,196 +60,156 @@ StartupConfig::StartupConfig() {
 
 // Print out user help
 void StartupConfig::printHelp() {
-    QString help = QString("usage: " NN_APP_NAME " <command>\n"
-                           + QString("  <command> options:\n\n")
-                           + QString("  help or ? or --? or --help           Show this message\n")
-                           + QString(
-        "  start <options>                      Start NixNote GUI with the specified options.\n")
-                           + QString(
-        "                                       If no command is specified, this is the default.\n")
-                           + QString("     start options:\n")
-                           + QString(
-        "          --logLevel=<level>           Set initial logging level (0=trace,1=debug,2=info,3=error,..\n")
-                           + QString(
-        "                                       This is ONLY valid at program startup until settings are read.\n")
-                           + QString("          --accountId=<id>             Start with specified user account.\n")
-
-                           // see FileManager.getConfigDir() for more info
-                           + QString("          --configDir=<dir>            Directory containing config files.\n")
-                           +
-                           QString("          --userDataDir=<dir>          Directory containing database, logs etc..\n")
-                           + QString(
-        "                                       Warning: ff you set configDir, but don't set userDataDir; userDataDir defaults\n")
-                           + QString("                                       to configDir.\n")
-                           + QString(
-        "          --programDataDir=<dir>       Directory containing deployed fixed program data (like images).\n")
-
-                           + QString("          --dontStartMinimized         Override option to start minimized.\n")
-                           + QString("          --disableEditing             Disable note editing\n")
-                           + QString(
-        "          --enableIndexing             Enable background Indexing (can cause problems)\n")
-                           + QString("          --openNote=<lid>             Open a specific note on startup\n")
-                           + QString("          --forceSystemTrayAvailable   Force the program to accept that\n")
-                           + QString("                                       the desktop supports tray icons.\n")
-                           + QString("          --startMinimized             Force a startup with NixNote minimized\n")
-                           + QString(
-        "  sync                                 Synchronize with Evernote without showing GUI.\n")
-                           + QString("  shutdown                             If running, ask NixNote to shutdown\n")
-                           + QString(
-        "  show_window                          If running, ask NixNote to show the main window.\n")
-                           + QString(
-        "  query <options>                      If running, search NixNote and display the results.\n")
-                           + QString("     query options:\n")
-                           + QString("          --search=\"search string\"     Search string.\n\n")
-                           + QString(
-        "          --delimiter=\"character\"      Character to place between fields.  Defaults to |.\n")
-                           + QString("          --noHeaders                  Do not show column headings.")
-                           + QString("          --display=\"<output format>\"  Search string.\n\n")
-                           + QString("             Output Format: <fieldID><padding><:>\n")
-                           + QString("                %i                     Show the internal note ID.\n")
-                           + QString("                %t                     Show the note title.\n")
-                           + QString("                %n                     Show the notebook.\n")
-                           + QString("                %g                     Show tags.\n")
-                           + QString("                %c                     Show the date the note was created.\n")
-                           + QString("                %u                     Show the last date updated.\n")
-                           + QString("                %e                     Show if the note is synchronized with Evernote.\n")
-                           + QString("                %s                     Show the source URL.\n")
-                           + QString("                %a                     Show the author.\n")
-                           + QString("                %x                     Show if the note has a todo item.\n")
-                           + QString("                %r                     Show the reminder time.\n")
-                           +
-                           QString("                %v                     Show the time the reminder was completed.\n")
-                           + QString(
-        "                <padding>              Pad the field to this number of spaces on the display.\n")
-                           + QString(
-        "                <:>                    Truncate the field if longer than the padding.\n")
-                           + QString("  addNote <options>                    Add a new note via the command line.\n")
-                           + QString("     addNote options:\n")
-                           + QString("          --title=\"<title>\"            Title of the new note.\n")
-                           + QString("          --notebook=\"<notebook>\"      Notebook for the new note.\n")
-                           + QString("          --tag=\"<tag>\"                Assign a tag.\n")
-                           + QString(
-        "                                       For multiple tags use multiple --tag statements.\n")
-                           + QString("          --attachment=\"<file_path>\"   File to attach to the note.\n")
-                           + QString(
-        "                                       For multiple files, use multiple --attachment statements.\n")
-                           + QString(
-        "          --delimiter=\"<delmiiter>\"    Character string identifying attachment points.\n")
-                           + QString("                                       Defaults to %%.\n")
-                           + QString(
-        "          --created=\"<datetime>\"   Date & time created in yyyy-MM-ddTHH:mm:ss.zzzZ format.\n")
-                           + QString(
-        "          --updated=\"<datetime>\"   Date & time updated in yyyy-MM-ddTHH:mm:ss.zzzZ format.\n")
-                           + QString(
-        "          --reminder=\"<datetime>\"  Reminder date & time in yyyy-MM-ddTHH:mm:ss.zzzZ format.\n")
-                           + QString(
-        "          --noteText=\"<text>\"          Text of the note.  If not provided input\n")
-                           + QString("                                       is read from stdin.\n")
-                           + QString("  appendNote <options>                 Append to an existing note.\n")
-                           + QString("     appendNote options:\n")
-                           + QString("          --id=\"<title>\"               ID of note to append.\n")
-                           + QString("          --attachment=\"<file_path>\"   File to attach to the note.\n")
-                           + QString(
-        "                                       For multiple files, use multiple --attachment statements.\n")
-                           + QString(
-        "          --delimiter=\"<delmiiter>\"    Character string identifying attachment points.\n")
-                           + QString("                                       Defaults to %%.\n")
-                           + QString(
-        "          --noteText=\"<text>\"          Text of the note.  If not provided input\n")
-                           + QString("                                       is read from stdin.\n")
-                           + QString("  alterNote <options>                  Change a note's notebook or tags.\n")
-                           + QString("     alterNote options:\n")
-                           + QString(
-        "          --id=\"<note_ids>\"            Space separated list of note IDs to extract.\n")
-                           + QString("          --search=\"search string\"     Alter notes matching search string.\n")
-                           + QString("          --notebook=\"<notebook>\"      Move matching notes to this notebook.\n")
-                           + QString("          --addTag=\"<tag_name>\"        Add this tag to matching notes.\n")
-                           + QString("          --delTag=\"<tag_name>\"        Remove this tag from matching notes.\n")
-                           + QString(
-        "          --reminder=\"<datetime>\"      Set a reminder in yyyy-MM-ddTHH:mm:ss.zzzZ format")
-                           + QString("          --reminderClear              Clear the note's reminder.\n")
-                           + QString("          --reminderComplete           Set the reminder as complete.\n")
-                           + QString(
-        "                                       yyyy-MM-ddTHH:mm:ss.zzzZ format or the literal 'now' to default\n")
-                           + QString("                                       to the current date & time.")
-                           + QString("  readNote <options>                   Read the text contents of a note.\n")
-                           + QString("          --id=\"<note_id>\"             ID of the note to read.\n")
-                           + QString(
-        "  deleteNote <options>                 Move a note to the trash via the command line.\n")
-                           + QString("     deleteNote options:\n")
-                           + QString("          --id=\"<note_id>\"             ID of the note to delete.\n")
-                           + QString("          --noVerify                   Do not prompt for verification.\n")
-                           + QString(
-        "  emailNote <options>                  Email a note via the command line.\n")
-                           + QString("     emailNote options:\n")
-                           + QString("          --id=\"<note_id>\"             ID of the note to email.\n")
-                           + QString("          --subject=\"<subject>\"        Subject for the email.\n")
-                           + QString("          --to=\"<address list>\"        List of recipients for the email.\n")
-                           + QString("          --cc=\"<address list>\"        List of recipients to carbon copy.\n")
-                           + QString(
-        "          --bcc=\"<address list>\"       List of recipients to blind carbon copy.\n")
-                           + QString("          --note=\"<note>\"              Additional comments.\n")
-                           + QString("          --ccSelf                     Send a copy to yourself.\n")
-                           + QString("  backup <options>                     Backup the NixNote database.\n")
-                           + QString("     backup options:\n")
-                           + QString("          --output=<filename>          Output filename.\n")
-                           + QString("  export <options>                     Export notes from NixNote.\n")
-                           + QString("     export options:\n")
-                           + QString(
-        "          --id=\"<note_ids>\"            Space separated list of note IDs to extract.\n")
-                           + QString("          --search=\"search string\"     Export notes matching search string.\n")
-                           + QString("          --output=\"filename\"          Output file name.\n")
-                           +
-                           QString("          --deleteAfterExtract         Delete notes after the extract completes.\n")
-                           + QString("          --noVerifyDelete             Don't verify deletions.\n")
-                           + QString(
-        "  import <options>                     Import notes from a NixNote extract (.nnex).\n")
-                           + QString("     import options:\n")
-                           + QString("          --input=\"filename\"           Input file name.\n")
-                           + QString("  closeNotebook <options>              Close a notebook.\n")
-                           + QString("     closeNotebook options:\n")
-                           + QString("          --notebook=\"notebook\"        Notebook name.\n")
-                           + QString("  openNotebook <options>               Open a closed notebook.\n")
-                           + QString("     openNotebook options:\n")
-                           + QString("          --notebook=\"notebook\"        Notebook name.\n")
-                           + QString("  signalGui <options>                  Send command to a running NixNote.\n")
-                           + QString("     signalGui options:\n")
-                           + QString("          --show                       Show NixNote if hidden.\n")
-                           + QString("          --synchronize                Synchronize with Evernote.\n")
-                           + QString("          --shutdown                   Shutdown NixNote.\n")
-                           + QString(
-        "          --openNote                   Open a note.  --id=<id> must be specified.\n")
-                           + QString(
-        "          --openNoteNewTab             Open a note in a new tab.  --id=<id> must be specified.\n")
-                           + QString(
-        "          --openExternalNote           Open a note in an external window.  --id=<id> must be specified.\n")
-                           + QString("          --id=<id>                    Note Id to open.\n")
-                           + QString("          --newNote                    Create a new note.\n")
-                           +
-                           QString("          --newExternalNote            Create a new note in an external window.\n")
-                           + QString("  Examples:\n\n")
-                           + QString("     To start NixNote using a secondary account.\n")
-                           + QString("     " NN_APP_NAME " --accountId=2\n\n")
-                           + QString("     To close an open notebook.\n")
-                           + QString("     " NN_APP_NAME " --closeNotebook notebook=\"My Notebook\"\n\n")
-                           + QString("     To add a note to the notebook \"My Notebook\"\n")
-                           + QString(
-        "     " NN_APP_NAME " addNote --notebook=\"My Stuff\" --title=\"My New Note\" --tag=\"Tag1\" --tag=\"Tag2\" --noteText=\"My Note Text\"\n\n")
-                           + QString("     To append to an existing note.\n")
-                           + QString("     " NN_APP_NAME " appendNote --id=3 --noteText=\"My Note Text\"\n\n")
-                           + QString("     To add a tag to notes in the notebook \"Stuff\".\n")
-                           + QString("     " NN_APP_NAME " alterNote --search=\"notebook:Stuff\" --addTag=\"NewTag\"\n\n")
-                           + QString(
-        "     Query notes for the search text. Results show the ID, note title (padded to 10 characters but truncated longer) and the notebook\n")
-                           + QString(
-        "     " NN_APP_NAME " query --search=\"Famous Authors\" --delimiter=\" * \" --display=\"\%i%t10:%n\"\n\n")
-                           + QString("     To extract all notes in the \"Notes\" notebook.\n")
-                           + QString(
-        "     " NN_APP_NAME " export --search=\"notebook:notes\" --output=/home/joe/exports.nnex\n\n")
-                           + QString(
-        "     To signal NixNote to do a shutdown (NixNote must already be running).\n")
-                           + QString("     " NN_APP_NAME " signalGui --shutdown\n\n")
-                           + QString("\n\n")
+    QString help = QString(
+        "usage: " NN_APP_NAME " <command>\n"
+        + QString("  <command> options:\n\n")
+        + QString("  help or ? or --? or --help           Show this message\n")
+        + QString("  start <options>                      Start NixNote GUI with the specified options.\n")
+        + QString("                                       If no command is specified, this is the default.\n")
+        + QString("     start options:\n")
+        + QString("          --logLevel=<level>           Set initial logging level (0=trace,1=debug,2=info,3=error,..\n")
+        + QString("                                       This is ONLY valid at program startup until settings are read.\n")
+        + QString("          --accountId=<id>             Start with specified user account.\n")
+        // see FileManager.getConfigDir() for more info
+        + QString("          --configDir=<dir>            Directory containing config files.\n")
+        + QString("          --userDataDir=<dir>          Directory containing database, logs etc..\n")
+        + QString("                                       Warning: ff you set configDir, but don't set userDataDir; userDataDir defaults\n")
+        + QString("                                       to configDir.\n")
+        + QString("          --programDataDir=<dir>       Directory containing deployed fixed program data (like images).\n")
+        + QString("          --dontStartMinimized         Override option to start minimized.\n")
+        + QString("          --disableEditing             Disable note editing\n")
+        + QString("          --enableIndexing             Enable background Indexing (can cause problems)\n")
+        + QString("          --openNote=<lid>             Open a specific note on startup\n")
+        + QString("          --forceSystemTrayAvailable   Force the program to accept that\n")
+        + QString("                                       the desktop supports tray icons.\n")
+        + QString("          --startMinimized             Force a startup with NixNote minimized\n")
+        + QString("  sync                                 Synchronize with Evernote without showing GUI.\n")
+        + QString("  shutdown                             If running, ask NixNote to shutdown\n")
+        + QString("  show_window                          If running, ask NixNote to show the main window.\n")
+        + QString("  query <options>                      If running, search NixNote and display the results.\n")
+        + QString("     query options:\n")
+        + QString("          --search=\"search string\"     Search string.\n\n")
+        + QString("          --delimiter=\"character\"      Character to place between fields.  Defaults to |.\n")
+        + QString("          --noHeaders                  Do not show column headings.")
+        + QString("          --display=\"<output format>\"  Search string.\n\n")
+        + QString("             Output Format: <fieldID><padding><:>\n")
+        + QString("                %i                     Show the internal note ID.\n")
+        + QString("                %t                     Show the note title.\n")
+        + QString("                %n                     Show the notebook.\n")
+        + QString("                %g                     Show tags.\n")
+        + QString("                %c                     Show the date the note was created.\n")
+        + QString("                %u                     Show the last date updated.\n")
+        + QString("                %e                     Show if the note is synchronized with Evernote.\n")
+        + QString("                %s                     Show the source URL.\n")
+        + QString("                %a                     Show the author.\n")
+        + QString("                %x                     Show if the note has a todo item.\n")
+        + QString("                %r                     Show the reminder time.\n")
+        + QString("                %v                     Show the time the reminder was completed.\n")
+        + QString("                <padding>              Pad the field to this number of spaces on the display.\n")
+        + QString("                <:>                    Truncate the field if longer than the padding.\n")
+        + QString("  addNote <options>                    Add a new note via the command line.\n")
+        + QString("     addNote options:\n")
+        + QString("          --title=\"<title>\"            Title of the new note.\n")
+        + QString("          --notebook=\"<notebook>\"      Notebook for the new note.\n")
+        + QString("          --tag=\"<tag>\"                Assign a tag.\n")
+        + QString("                                       For multiple tags use multiple --tag statements.\n")
+        + QString("          --attachment=\"<file_path>\"   File to attach to the note.\n")
+        + QString("                                       For multiple files, use multiple --attachment statements.\n")
+        + QString("          --delimiter=\"<delmiiter>\"    Character string identifying attachment points.\n")
+        + QString("                                       Defaults to %%.\n")
+        + QString("          --created=\"<datetime>\"   Date & time created in yyyy-MM-ddTHH:mm:ss.zzzZ format.\n")
+        + QString("          --updated=\"<datetime>\"   Date & time updated in yyyy-MM-ddTHH:mm:ss.zzzZ format.\n")
+        + QString("          --reminder=\"<datetime>\"  Reminder date & time in yyyy-MM-ddTHH:mm:ss.zzzZ format.\n")
+        + QString("          --noteText=\"<text>\"          Text of the note.  If not provided input\n")
+        + QString("                                       is read from stdin.\n")
+        + QString("  appendNote <options>                 Append to an existing note.\n")
+        + QString("     appendNote options:\n")
+        + QString("          --id=\"<title>\"               ID of note to append.\n")
+        + QString("          --attachment=\"<file_path>\"   File to attach to the note.\n")
+        + QString("                                       For multiple files, use multiple --attachment statements.\n")
+        + QString("          --delimiter=\"<delmiiter>\"    Character string identifying attachment points.\n")
+        + QString("                                       Defaults to %%.\n")
+        + QString("          --noteText=\"<text>\"          Text of the note.  If not provided input\n")
+        + QString("                                       is read from stdin.\n")
+        + QString("  alterNote <options>                  Change a note's notebook or tags.\n")
+        + QString("     alterNote options:\n")
+        + QString("          --id=\"<note_ids>\"            Space separated list of note IDs to extract.\n")
+        + QString("          --search=\"search string\"     Alter notes matching search string.\n")
+        + QString("          --notebook=\"<notebook>\"      Move matching notes to this notebook.\n")
+        + QString("          --addTag=\"<tag_name>\"        Add this tag to matching notes.\n")
+        + QString("          --delTag=\"<tag_name>\"        Remove this tag from matching notes.\n")
+        + QString("          --reminder=\"<datetime>\"      Set a reminder in yyyy-MM-ddTHH:mm:ss.zzzZ format")
+        + QString("          --reminderClear              Clear the note's reminder.\n")
+        + QString("          --reminderComplete           Set the reminder as complete.\n")
+        + QString("                                       yyyy-MM-ddTHH:mm:ss.zzzZ format or the literal 'now' to default\n")
+        + QString("                                       to the current date & time.")
+        + QString("  readNote <options>                   Read the text contents of a note.\n")
+        + QString("          --id=\"<note_id>\"             ID of the note to read.\n")
+        + QString("  deleteNote <options>                 Move a note to the trash via the command line.\n")
+        + QString("     deleteNote options:\n")
+        + QString("          --id=\"<note_id>\"             ID of the note to delete.\n")
+        + QString("          --noVerify                   Do not prompt for verification.\n")
+        + QString("  emailNote <options>                  Email a note via the command line.\n")
+        + QString("     emailNote options:\n")
+        + QString("          --id=\"<note_id>\"             ID of the note to email.\n")
+        + QString("          --subject=\"<subject>\"        Subject for the email.\n")
+        + QString("          --to=\"<address list>\"        List of recipients for the email.\n")
+        + QString("          --cc=\"<address list>\"        List of recipients to carbon copy.\n")
+        + QString("          --bcc=\"<address list>\"       List of recipients to blind carbon copy.\n")
+        + QString("          --note=\"<note>\"              Additional comments.\n")
+        + QString("          --ccSelf                     Send a copy to yourself.\n")
+        + QString("  backup <options>                     Backup the NixNote database.\n")
+        + QString("     backup options:\n")
+        + QString("          --output=<filename>          Output filename.\n")
+        + QString("  export <options>                     Export notes from NixNote.\n")
+        + QString("     export options:\n")
+        + QString("          --id=\"<note_ids>\"            Space separated list of note IDs to extract.\n")
+        + QString("          --search=\"search string\"     Export notes matching search string.\n")
+        + QString("          --output=\"filename\"          Output file name.\n")
+        + QString("          --deleteAfterExtract         Delete notes after the extract completes.\n")
+        + QString("          --noVerifyDelete             Don't verify deletions.\n")
+        + QString("  import <options>                     Import notes from a NixNote extract (.nnex).\n")
+        + QString("     import options:\n")
+        + QString("          --input=\"filename\"           Input file name.\n")
+        + QString("  closeNotebook <options>              Close a notebook.\n")
+        + QString("     closeNotebook options:\n")
+        + QString("          --notebook=\"notebook\"        Notebook name.\n")
+        + QString("  openNotebook <options>               Open a closed notebook.\n")
+        + QString("     openNotebook options:\n")
+        + QString("          --notebook=\"notebook\"        Notebook name.\n")
+        + QString("  signalGui <options>                  Send command to a running NixNote.\n")
+        + QString("     signalGui options:\n")
+        + QString("          --show                       Show NixNote if hidden.\n")
+        + QString("          --synchronize                Synchronize with Evernote.\n")
+        + QString("          --shutdown                   Shutdown NixNote.\n")
+        + QString("          --openNote                   Open a note.  --id=<id> must be specified.\n")
+        + QString("          --openNoteNewTab             Open a note in a new tab.  --id=<id> must be specified.\n")
+        + QString("          --openExternalNote           Open a note in an external window.  --id=<id> must be specified.\n")
+        + QString("          --openNoteUrl                Open a note from a URL.  --url=<url> must be specified.\n")
+        + QString("          --openNoteNewTabUrl          Open a note in a new tab from a URL.  --url=<url> must be specified.\n")
+        + QString("          --openExternalNoteUrl        Open a note in an external window from a URL.  --url=<url> must be specified.\n")
+        + QString("          --id=<id>                    Note Id to open.\n")
+        + QString("          --url=<id>                   In-app or external URL for the Note to open.\n")
+        + QString("          --newNote                    Create a new note.\n")
+        + QString("          --newExternalNote            Create a new note in an external window.\n")
+        + QString("  Examples:\n\n")
+        + QString("     To start NixNote using a secondary account.\n")
+        + QString("     " NN_APP_NAME " --accountId=2\n\n")
+        + QString("     To close an open notebook.\n")
+        + QString("     " NN_APP_NAME " --closeNotebook notebook=\"My Notebook\"\n\n")
+        + QString("     To add a note to the notebook \"My Notebook\"\n")
+        + QString("     " NN_APP_NAME " addNote --notebook=\"My Stuff\" --title=\"My New Note\" --tag=\"Tag1\" --tag=\"Tag2\" --noteText=\"My Note Text\"\n\n")
+        + QString("     To append to an existing note.\n")
+        + QString("     " NN_APP_NAME " appendNote --id=3 --noteText=\"My Note Text\"\n\n")
+        + QString("     To add a tag to notes in the notebook \"Stuff\".\n")
+        + QString("     " NN_APP_NAME " alterNote --search=\"notebook:Stuff\" --addTag=\"NewTag\"\n\n")
+        + QString("     Query notes for the search text. Results show the ID, note title (padded to 10 characters but truncated longer) and the notebook\n")
+        + QString("     " NN_APP_NAME " query --search=\"Famous Authors\" --delimiter=\" * \" --display=\"\%i%t10:%n\"\n\n")
+        + QString("     To extract all notes in the \"Notes\" notebook.\n")
+        + QString("     " NN_APP_NAME " export --search=\"notebook:notes\" --output=/home/joe/exports.nnex\n\n")
+        + QString("     To signal NixNote to do a shutdown (NixNote must already be running).\n")
+        + QString("     " NN_APP_NAME " signalGui --shutdown\n\n")
+        + QString("\n\n")
     );
 
     std::cout << help.toStdString(); // ok to use cout => help text
@@ -292,10 +252,14 @@ int StartupConfig::init(int argc, char *argv[], bool &guiAvailable) {
 
 // Windows Check
 #ifndef _WIN32
+#ifndef Q_OS_MACOS
     QString display = QProcessEnvironment::systemEnvironment().value("DISPLAY", "");
-    if (display.trimmed() == "")
+    if (display.trimmed() == "") {
+        QLOG_DEBUG() << "It seems no display was found => guiAvailable=false";
         guiAvailable = false;
-#endif // End windows check
+    }
+#endif // end maxcOS
+#endif // end windows check
 
     // although this will contain the path used to start the binary (even in case of AppImage)
     // if the app was started via system path, then the path will not be present
@@ -591,6 +555,11 @@ int StartupConfig::init(int argc, char *argv[], bool &guiAvailable) {
                 parm = parm.mid(5);
                 signalGui->lid = parm.toInt();
             }
+            if (parm.startsWith("--url=", Qt::CaseSensitive)) {
+                parm = parm.mid(6);
+                signalGui->url = parm;
+                QLOG_DEBUG() << "got url from params: " << parm;
+            }
             if (parm.startsWith("--show", Qt::CaseSensitive))
                 signalGui->show = true;
             if (parm.startsWith("--synchronize", Qt::CaseSensitive))
@@ -599,10 +568,16 @@ int StartupConfig::init(int argc, char *argv[], bool &guiAvailable) {
                 signalGui->takeScreenshot = true;
             if (parm.startsWith("--openNote", Qt::CaseSensitive))
                 signalGui->openNote = true;
+            if (parm.startsWith("--openNoteUrl", Qt::CaseSensitive))
+                signalGui->openNoteUrl = true;
             if (parm.startsWith("--openExternalNote", Qt::CaseSensitive))
                 signalGui->openExternalNote = true;
+            if (parm.startsWith("--openExternalNoteUrl", Qt::CaseSensitive))
+                signalGui->openExternalNoteUrl = true;
             if (parm.startsWith("--openNoteNewTab", Qt::CaseSensitive))
                 signalGui->openNoteNewTab = true;
+            if (parm.startsWith("--openNoteNewTabUrl", Qt::CaseSensitive))
+                signalGui->openNoteNewTabUrl = true;
             if (parm.startsWith("--newNote", Qt::CaseSensitive))
                 signalGui->newNote = true;
             if (parm.startsWith("--newExternalNote", Qt::CaseSensitive))
